summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser_main.cc
diff options
context:
space:
mode:
authorjar@chromium.org <jar@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-25 00:12:49 +0000
committerjar@chromium.org <jar@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-25 00:12:49 +0000
commit74be069e808f687ab33d7bec52d1c9687af1b3ec (patch)
tree9b830fa01634cb18cd886ea8758cf62e747fc480 /chrome/browser/browser_main.cc
parentd07f0c801dbb2fdb6fcfaa671afa13400a615c85 (diff)
downloadchromium_src-74be069e808f687ab33d7bec52d1c9687af1b3ec.zip
chromium_src-74be069e808f687ab33d7bec52d1c9687af1b3ec.tar.gz
chromium_src-74be069e808f687ab33d7bec52d1c9687af1b3ec.tar.bz2
Change classes and functions for DNS Prefetching to Predictor*
The DNS prefetching system has been extended to handle TCP/IP preconnection. As a result, class names and function names will be migrated to variations on Predictor* and Predict* to better indicate functionality. This change is only meant to include name changes, comment updates, and no semantic changes. r=mbelshe Review URL: http://codereview.chromium.org/2813031 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@50792 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/browser_main.cc')
-rw-r--r--chrome/browser/browser_main.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/chrome/browser/browser_main.cc b/chrome/browser/browser_main.cc
index a2bc534..ca77eb6 100644
--- a/chrome/browser/browser_main.cc
+++ b/chrome/browser/browser_main.cc
@@ -1022,7 +1022,7 @@ int BrowserMain(const MainFunctionParams& parameters) {
BrowserInit browser_init;
// On first run, we need to process the master preferences before the
// browser's profile_manager object is created, but after ResourceBundle
// is initialized.
FirstRun::MasterPrefs master_prefs = { 0 };
@@ -1265,9 +1265,11 @@ int BrowserMain(const MainFunctionParams& parameters) {
// testing against a bunch of special cases that are taken care early on.
PrepareRestartOnCrashEnviroment(parsed_command_line);
- // Initialize and maintain DNS prefetcher module. Also registers an observer
- // to clear the host cache when closing incognito mode.
- chrome_browser_net::DnsGlobalInit dns_prefetch(
+ // Initialize and maintain network predictor module, which handles DNS
+ // pre-resolution, as well as TCP/IP connection pre-warming.
+ // This also registers an observer to discard data when closing incognito
+ // mode.
+ chrome_browser_net::PredictorInit dns_prefetch(
user_prefs,
local_state,
parsed_command_line.HasSwitch(switches::kEnablePreconnect));
@@ -1022,7 +1022,7 @@ int BrowserMain(const MainFunctionParams& parameters) {
BrowserInit browser_init;
- // On first run, we need to process the master preferences before the
+ // On first run, we need to process the predictor preferences before the
// browser's profile_manager object is created, but after ResourceBundle
// is initialized.